@@ -23,21 +23,30 @@
 """
 
 __author__ = 'Jacques Supcik'
+__version  = '0.1.3'
 
 import httplib
 import random
-import re
 import xml.dom.minidom
 from warnings import warn
 from aspsms.aspxml import aspxml
 
-def _sms_encode(s):
-    return re.sub(
-        r'[\x26\x3c\x3e\x80-\xff]',
-        lambda c: '&#'+str(ord(c.group(0)))+';',
-        unicode(s, 'utf-8').encode("iso8859_15")
-    )
-
+valid_action = {
+  'send_random_logo'               : 'SendRandomLogo',
+  'send_text_sms'                  : 'SendTextSMS',
+  'send_picture_message'           : 'SendPictureMessage',
+  'send_logo'                      : 'SendLogo',
+  'send_group_logo'                : 'SendGroupLogo',
+  'send_ringtone'                  : 'SendRingtone',
+  'inquire_delivery_notifications' : 'InquireDeliveryNotifications',
+  'show_credits'                   : 'ShowCredits',
+  'send_vcard'                     : 'SendVCard',
+  'send_binary_data'               : 'SendBinaryData',
+  'send_wap_push_sms'              : 'SendWAPPushSMS',
+  'send_originator_unlock_code'    : 'SendOriginatorUnlockCode',
+  'unlock_originator'              : 'UnlockOriginator',
+  'check_originator_authorization' : 'CheckOriginatorAuthorization'
+}
 
 class ASPSMS(object):
     """Main Class
@@ -46,20 +55,18 @@ class ASPSMS(object):
     #Default values for members
     reply = None
 
-    def __init__(self, user_key=None, password=None, originator=None):
+    def __init__(self, **kwargs):
         """Creates a new ASMSMS object"""
 
-        self.user_key = user_key
-	self.password = password
-	self.originator = originator
+        self.message = aspxml(**kwargs)
 
     def reply_attribute(self, attribute):
         """"Extracts an attribute from the reply"""
 
-	i=self.reply.getElementsByTagName(attribute).item(0)
-	return (i != None and i.firstChild.data) or None
+        i=self.reply.getElementsByTagName(attribute).item(0)
+        return (i != None and i.firstChild.data) or None
 
-    def __send(self, message):
+    def __send(self):
         """Sends the message"""
 
         urls = [
@@ -72,7 +79,7 @@ class ASPSMS(object):
             try:
                 url = urls.pop(0)
                 conn = httplib.HTTPConnection(url)
-                conn.request("POST", "/xmlsvr.asp", str(message))
+                conn.request("POST", "/xmlsvr.asp", str(self.message))
                 r = conn.getresponse()
                 reply = r.read()
                 if r.status == 200:
@@ -82,39 +89,26 @@ class ASPSMS(object):
                 warn("%s / error using %s" % (inst, url))
   
         self.reply = xml.dom.minidom.parseString(reply)
-	self.error_code = self.reply_attribute("ErrorCode")
-	self.error_description = self.reply_attribute("ErrorDescription")
+        self.error_code = self.reply_attribute("ErrorCode")
+        self.error_description = self.reply_attribute("ErrorDescription")
 
-    def send_text_sms(self, recipient, text, originator=None):
-        """Sends a text sms
+    def __getattr__(self, name):
+        def decorated(*args, **kwargs):
+            return self.action(name, *args, **kwargs)
 
-        Args:
-          originator: str
-          recipient: str
-          text: str
-        """
+        if valid_action.has_key(name):
+            return decorated
+        else:
+            raise AttributeError
 
-        originator = originator or self.originator
-        message = aspxml(self.user_key, self.password)
-        if originator:
-            message.tag('Originator', originator)
-        message.open_tag('Recipient')
-        message.tag('PhoneNumber', recipient)
-        message.tag('UsedCredits', 1)
-        message.close_tag()
-        message.tag('MessageData', _sms_encode(text.strip()))
-        message.tag('Action', 'SendTextSMS')
-        self.__send(message)
+    def set (self, **kwargs):
+        for key in kwargs:
+            setattr(self.message, key, kwargs[key])
 
-    def show_credits(self):
-        """Show credits
+    def action(self, name, **kwargs):
+        for key in kwargs:
+            setattr(self.message, key, kwargs[key])
 
-        Returns:
-          the remaining credits.
-        """
-
-        message = aspxml(self.user_key, self.password)
-        message.tag("Action", "ShowCredits")
-        self.__send(message)
-	return self.reply_attribute("Credits")
+        self.message.Action = valid_action[name]
+        self.__send()
 
